Name:           LuxRender
Version:        0.5
Release:        5%{?dist}
Summary:        Lux Renderer, an unbiased rendering system

Group:          Applications/Multimedia
License:        GPLv3+ and BSD
URL:            http://www.luxrender.net
Source0:        http://www.luxrender.net/downloads/v05_release/LuxRender_v05_Source.zip
Source1:        http://www.luxrender.net/downloads/v05_release/LuxBlend_v05_Blender_Exporter.zip
Source2:        luxblend-default.cfg
Patch0:         LuxRender_v05-shared.patch
Patch1:         lux-0.5-intrinsic.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  cmake

BuildRequires:  bison
BuildRequires:  boost-devel
BuildRequires:  flex
BuildRequires:  fltk-devel
BuildRequires:  libpng-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  OpenEXR-devel
BuildRequires:  wxGTK-devel

BuildRequires:  libXdamage-devel

Requires:  %{name}-core = %{version}-%{release}


%description
LuxRender is a rendering system for physically correct image synthesis.

%package lib
Summary:        Libraries for %{name}
Group:          System Environment/Libraries

%description lib
The %{name}-lib package contains shared library for %{name}.

%package        core
Summary:        Core binaries for %{name}
Group:          Applications/Multimedia
Requires:       %{name}-lib = %{version}-%{release}

%description    core
The %{name}-core package contains core binaries for using %{name}.

%package        blender
Summary:        Blender export plugin to %{name}
Group:          Applications/Multimedia
Requires:       %{name} = %{version}-%{release}
Requires:       blender >= 2.48a-22

%description    blender
The %{name}-blender package contains the plugin for Blender
to export into %{name}

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        devel-docs
Summary:        Documentation for developing %{name} applications
Group:          Documentation

%description devel-docs
The %{name}-devel-docs package contains the documentation needed to develop
applications with %{name}.


%prep
%setup -q -n lux
%setup -q -D -T -a 1 -n lux
%patch0 -p1 -b .shared
%patch1 -p1 -b .intrinsic
install -pm 0644 core/SFMT/LICENSE.txt LICENSE-SFMT.txt
#Disable tweaking
sed -i -e 's/-O3 -msse2 -mfpmath=sse -ftree-vectorize -funroll-loops -Wall//' CMakeLists.txt


for f in AUTHORS.txt COPYING.txt LICENSE-SFMT.txt ; do
  cp -p ${f} ${f}.ref
  sed -i 's/\r//' ${f}
  touch -r ${f}.ref ${f}
  rm ${f}.ref
done

#Disable wrong-end-of-line-encoding
sed -i 's|\r||' LuxBlend_0.1.py


%build
mkdir -p build
pushd build

%cmake \
  -DCMAKE_VERBOSE_MAKEFILE:BOOL=TRUE \
  -DCMAKE_SKIP_RPATH:BOOL=ON \
%if %{?_lib} == "lib64"
  -DLIBDIR=%{_lib} \
%endif
  ..

make %{?_smp_mflags} VERBOSE=1

popd

# generate doc
pushd doxygen
  doxygen doxygen.conf
popd


%install
rm -rf $RPM_BUILD_ROOT
pushd build

make install DESTDIR=$RPM_BUILD_ROOT

popd

desktop-file-install --vendor "" --delete-original \
  --dir $RPM_BUILD_ROOT%{_datadir}/applications \
  --remove-category Application \
  $RPM_BUILD_ROOT%{_datadir}/applications/luxrender.desktop

install -pm 0755 build/wxluxgui $RPM_BUILD_ROOT%{_bindir}

mkdir -p $RPM_BUILD_ROOT%{_datadir}/blender/scripts/bpydata/config
install -pm 0644 LuxBlend_0.1.py $RPM_BUILD_ROOT%{_datadir}/blender/scripts/

install -pm 0644 %{SOURCE2} \
  $RPM_BUILD_ROOT%{_datadir}/blender/scripts/bpydata/config/luxblend.cfg


%clean
rm -rf $RPM_BUILD_ROOT


%post lib -p /sbin/ldconfig

%postun lib -p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%doc AUTHORS.txt COPYING.txt LICENSE-SFMT.txt
%{_bindir}/wxluxgui
%{_bindir}/luxrender
%{_datadir}/pixmaps/luxrender.svg
%{_datadir}/applications/luxrender.desktop

%files lib
%defattr(-,root,root,-)
%{_libdir}/*.so.*

%files core
%defattr(-,root,root,-)
%{_bindir}/luxconsole

%files blender
%defattr(-,root,root,-)
%{_datadir}/blender/scripts/LuxBlend_0.1.py*
%{_datadir}/blender/scripts/bpydata/config/luxblend.cfg

%files devel
%defattr(-,root,root,-)
%{_includedir}/luxrender/
%{_libdir}/*.so

%files devel-docs
%defattr(-,root,root,-)
%doc doxygen/html


%changelog
* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed May 13 2009 kwizart < kwizart at gmail.com > - 0.5-4
- Move %%doc from -lib to main
- Remove Requires main from -devel-docs
- Disable wrong-end-of-line-encoding for LuxBlend_0.1.py
- Add Requires: blender >= 2.48a-22 so the script will copy
  the default settings in the end-user directory.

* Tue Mar 17 2009 kwizart < kwizart at gmail.com > - 0.5-3
- Add luxblend-default.cfg

* Tue Jan 20 2009 kwizart < kwizart at gmail.com > - 0.5-2
- Fix compilation with boost 1.34 - (backport)
- Subpackage the Blender_Exporter plugin 
- Subpackage -devel-docs for doxygen docs.

* Wed Jul 23 2008 kwizart < kwizart at gmail.com > - 0.5-1
- Update to 0.5

* Mon Dec 17 2007 Romang Jean-Francois <jeanfrancois.romang@laposte.net> 0.1-rc4
-Initial version

